import time

# Import the preset TestFixture.
from .Frames_transmission_fixture import FixtureFramesTransmission, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestEthTransmitter(FixtureFramesTransmission):

    # Create setUp() method.
    def setUp(self):
        logger.info("setup test case")

    # Create the tearDown() method.
    def tearDown(self):
        logger.info("tear down test case")

    # Create the test case method that holds the main test steps.
    def test_eth_transmitter(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual invehicle communication.
        channel_name = 'Ethernet_MTF'
        payload = [0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
                   0xFF, 0x00, 0x50, 0xC2, 0xe4,
                   0x30, 0x00, 0x88, 0xB5, 0x21,
                   0x21, 0x54, 0x68, 0x69, 0x73,
                   0x20, 0x69, 0x73, 0x20, 0x61,
                   0x20, 0x64, 0x65, 0x62, 0x75,
                   0x67, 0x20, 0x66, 0x72, 0x61,
                   0x6d, 0x6e, 0x74, 0x20, 0x62,
                   0x79, 0x20, 0x6d, 0x74, 0x66,
                   0x20, 0x66, 0x72, 0x61, 0x6d,
                   0x65, 0x77]

        eth_ch = ChannelFactory().get_ethernet_channel(channel_name)

        # Log any useful message
        logger.info("Transmit an ethernet payload")

        # Transmit an ethernet payload.
        eth_transmit = eth_ch.transmitter.transmit_frame(payload)

        time.sleep(2)

        # Confirm the correct transmission by verifying the boolean return value of transmit_frame().
        # If there are no issues during transmission, the return value should
        # be true.
        self.assertTrue(eth_transmit, Severity.BLOCKER,
                        "Error when sending Ethernet payload")
